history
=======

Try to regenerate the history of your package based on information contained in
the list of associated tags. This tool works better if you have hosted your code
on either GitHub_ or Gitlab_ and have used the corresponding option.

Modifications
-------------


This tool will overwrite your HISTORY or CHANGELOG file.


Quick tutorial
--------------

Just call the tool at the root of your package::

    (dvlpt)$ pmg history

.. _GitHub: https://github.com/
.. _Gitlab: https://framagit.org/
